@@ -9,7 +9,7 @@ use Digest::SHA();
 use WebService::HIBP::Breach();
 use WebService::HIBP::Paste();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub _LENGTH_OF_PASSWORD_PREFIX { return 5; }
 
@@ -154,7 +154,7 @@ WebService::HIBP - An interface to the Have I Been Pwned webservice at haveibeen
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =head1 SYNOPSIS
 
@@ -187,9 +187,9 @@ a new C<WebService::HIBP> object, ready to check how bad the pwnage is.
 
 The L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords> has more than half a billion passwords which have previously been exposed in data breaches. The service is detailed in the L<launch blog post|https://www.troyhunt.com/introducing-306-million-freely-downloadable-pwned-passwords/> then L<further expanded on with the release of version 2|https://www.troyhunt.com/ive-just-launched-pwned-passwords-version-2>. 
 
-In order to protect the value of the source password being searched for, this method implements a L<k-Anonymity|https://en.wikipedia.org/wiki/K-anonymity> model that searches for a password by partial hash. This method sends the first 5 characters of a SHA-1 password hash (the prefix) to be passed to the L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords>.
+In order to protect the value of the source password being searched for, this method implements a L<k-Anonymity|https://en.wikipedia.org/wiki/K-anonymity> model that searches for a password by partial hash. This method therefore only sends the first 5 characters of a SHA-1 hash of the password (the prefix) to the L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords>.
 
-The L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords> will respond with a list of the suffix of every hash beginning with the specified prefix, followed by a count of how many times it appears in the data set. This method then searches the results of the response for the presence of their source hash. If not found, the password does not exist in the data set.  
+The L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords> responds with a list of the suffix of every hash beginning with the specified prefix, followed by a count of how many times it appears in the data set. This method then searches the results of the response for the presence of a matching hash suffix.
 
 This method then returns the count of how many times it appears in the data set or "0" if it dosen't appear.
 
@@ -223,7 +223,7 @@ Parameters:
 =back 
 
     use WebService::HIBP();
-	use v5.10;
+    use v5.10;
 
     my $hibp = WebService::HIBP->new();
     foreach my $breach ( $hibp->account( 'test@example.com', domain => 'adobe.com' ) ) {
@@ -235,11 +235,11 @@ Parameters:
 Sometimes just a single L<breach|WebService::HIBP::Breach> is required and this can be retrieved by the breach L<name|WebService::HIBP::Breach#name>. This is the stable value which may or may not be the same as the breach L<title|WebService::HIBP::Breach#title> (which can change). Returns a list of L<breaches|WebService::HIBP::Breach>.
 
     use WebService::HIBP();
-	use v5.10;
+    use v5.10;
 
     my $hibp = WebService::HIBP->new();
-    my $breach = $hibp->breach( 'Adobe' ) ) {
-	say $breach->title();
+    my $breach = $hibp->breach( 'Adobe' );
+    say $breach->title();
 
 =head2 breaches
 
@@ -255,7 +255,7 @@ Parameters:
 =back 
 
     use WebService::HIBP();
-	use v5.10;
+    use v5.10;
 
     my $hibp = WebService::HIBP->new();
     foreach my $breach ( $hibp->breaches( domain => 'adobe.com' ) ) {
@@ -267,7 +267,7 @@ Parameters:
 A "data class" is an attribute of a record compromised in a breach. For example, many breaches expose data classes such as "Email addresses" and "Passwords". The values returned by this service are ordered alphabetically in a string array and will expand over time as new breaches expose previously unseen classes of data.
 
     use WebService::HIBP();
-	use v5.10;
+    use v5.10;
 
     my $hibp = WebService::HIBP->new();
     foreach my $class ( $hibp->data_classes() ) {
@@ -279,7 +279,7 @@ A "data class" is an attribute of a record compromised in a breach. For example,
 This method takes a single parameter which is the email address to be searched for. Unlike searching for breaches, usernames that are not email addresses cannot be searched for. The email is not case sensitive and will be trimmed of leading or trailing white spaces.  Returns a list of L<pastes|WebService::HIBP::Paste>.
 
     use WebService::HIBP();
-	use v5.10;
+    use v5.10;
 
     my $hibp = WebService::HIBP->new();
     foreach my $paste ( $hibp->pastes( 'test@example.com' ) ) {
@@ -298,7 +298,7 @@ The URL could not be retrieved. Check network and proxy settings.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-WebService::HIBP requires no configuration files or environment variables.  However, it will use the values of C<$ENV{no_proxy}> and C<$ENV{HTTP_PROXY}> as defaults for calls to the L<https://haveibeenpwned.com/api/v2/> API via the LWP::UserAgent module.
+WebService::HIBP requires no configuration files or environment variables.  However, it will use the values of C<$ENV{HTTPS_PROXY}> as a default for calls to the L<https://haveibeenpwned.com/api/v2/> API via the LWP::UserAgent module.
 
 =head1 DEPENDENCIES
 
